/**-----------------------------------------------------------------------------------------
* Copyright © 2024 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { CompositeFilterDescriptor, FilterDescriptor } from '@progress/kendo-data-query';
import { ColumnComponent } from "../../columns/column.component";
import { FilterService } from '../filter.service';
import { NumericFilterComponent } from '../numeric-filter.component';
import { MenuTabbingService } from './menu-tabbing.service';
import { ContextService } from '../../common/provider.service';
import * as i0 from "@angular/core";
/**
 * Represents a numeric filter-menu component.
 *
 * @example
 * ```html
 * <kendo-grid-column field="UnitPrice">
 *   <ng-template kendoGridFilterMenuTemplate let-filter let-column="column" let-filterService="filterService">
 *     <kendo-grid-numeric-filter-menu
 *       [column]="column"
 *       [filter]="filter"
 *       [filterService]="filterService">
 *     </kendo-grid-numeric-filter-menu>
 *   </ng-template>
 * </kendo-grid-column>
 * ```
 */
export declare class NumericFilterMenuComponent extends NumericFilterComponent {
    logicOperators: Array<{
        text: string;
        value: "and" | "or";
    }>;
    /**
     * @hidden
     */
    get hostClasses(): boolean;
    /**
     * The column with which the filter is associated.
     * @type {ColumnComponent}
     */
    column: ColumnComponent;
    /**
     * The current menu filter.
     * @type {CompositeFilterDescriptor}
     */
    filter: CompositeFilterDescriptor;
    /**
     * Determines if the inputs of second criteria will displayed.
     * @default true
     */
    extra: boolean;
    /**
     * The `FilterService` instance which is responsible for handling the changes in the filter descriptor.
     */
    filterService: FilterService;
    /**
     * Determines the delay (in milliseconds) before creating a filter descriptor based on the value. A value of 0 indicates no delay. The default value is 500.
     *
     * @default 500
     */
    filterDelay: number;
    /**
     * The placeholder text for the filter input.
     * @type {string}
     */
    placeholder: string;
    /**
     * The placeholder text for the extra filter input. Applies when `extra` is set to `true`.
     * @type {string}
     */
    extraPlaceholder: string;
    /**
     * @hidden
     */
    menuTabbingService: MenuTabbingService;
    constructor(ctx: ContextService);
    get firstFilter(): FilterDescriptor;
    get secondFilter(): FilterDescriptor;
    logicChange(value: 'and' | 'or'): void;
    get filterMenuDropDownLabel(): string;
    protected localizationChange(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<NumericFilterMenuComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<NumericFilterMenuComponent, "kendo-grid-numeric-filter-menu", never, { "column": "column"; "filter": "filter"; "extra": "extra"; "filterService": "filterService"; "filterDelay": "filterDelay"; "placeholder": "placeholder"; "extraPlaceholder": "extraPlaceholder"; "menuTabbingService": "menuTabbingService"; }, {}, never, never, true, never>;
}
